==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/NativeUIButton.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { NativeUIComponent } from "./NativeUIComponent";
import { NativeUIDisplayDensity_$type } from "./NativeUIDisplayDensity";
import { enumGetBox, EnumUtil, markType } from "./type";
/**
 * @hidden
 */
export let NativeUIButton = /*@__PURE__*/ (() => {
    class NativeUIButton extends NativeUIComponent {
        constructor() {
            super(...arguments);
            this.at = null;
        }
        get_c() {
            return 1;
        }
        get av() {
            let a = this.o(1);
            return a == null ? 1 : EnumUtil.getEnumValue(NativeUIDisplayDensity_$type, a);
        }
        set av(a) {
            this.af(1, enumGetBox(NativeUIDisplayDensity_$type, a));
        }
        get aw() {
            let a = this.o(3);
            return a;
        }
        set aw(a) {
            this.af(3, a);
        }
        get au() {
            return this.at;
        }
        set au(a) {
            let b = this.at;
            this.at = a;
            if (this.at != null) {
                this.x(1, this.at);
            }
            else {
                this.ad(1, b);
            }
        }
    }
    NativeUIButton.$t = /*@__PURE__*/ markType(NativeUIButton, 'NativeUIButton', NativeUIComponent.$);
    return NativeUIButton;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/NativeUIButton.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { NativeUIComponent } from "./NativeUIComponent";
import { NativeUIDisplayDensity_$type } from "./NativeUIDisplayDensity";
import { enumGetBox, EnumUtil, markType } from "./type";
/**
 * @hidden
 */
export let NativeUIButton = /*@__PURE__*/ (() => {
    class NativeUIButton extends NativeUIComponent {
        constructor() {
            super(...arguments);
            this.ay = null;
        }
        get_e() {
            return 1;
        }
        get a0() {
            let a = this.q(1);
            return a == null ? 1 : EnumUtil.getEnumValue(NativeUIDisplayDensity_$type, a);
        }
        set a0(a) {
            this.ak(1, enumGetBox(NativeUIDisplayDensity_$type, a));
        }
        get a1() {
            let a = this.q(3);
            return a;
        }
        set a1(a) {
            this.ak(3, a);
        }
        get az() {
            return this.ay;
        }
        set az(a) {
            let b = this.ay;
            this.ay = a;
            if (this.ay != null) {
                this.z(1, this.ay);
            }
            else {
                this.ai(1, b);
            }
        }
    }
    NativeUIButton.$t = /*@__PURE__*/ markType(NativeUIButton, 'NativeUIButton', NativeUIComponent.$);
    return NativeUIButton;
})();
